#ifndef __CHIPINFO_H__
#define __CHIPINFO_H__

#include "firebrand-api.h"
#include "chipinfo-struct.h"


/*
 *  Define information storage for chips. Two types of information are
 *  stored: genetic and specific. Generic describes a hardware family
 *  and contains the information on how to setup the board. The specific
 *  information is about a particular manufacturer's specific chip. This
 *  contains all timing information.
 */

/* Locations:
 *   1 = ZIF (full)
 *   2 = ZIF (lower)
 *   3 = 
 *   4 =
 *   5 = 
 *   6 = 
 */

/* DIP switch settings (off by default) */
#define SW_DIP1  0x0001
#define SW_DIP2  0x0002
#define SW_DIP3  0x0004
#define SW_DIP4  0x0008
#define SW_DIP5  0x0010
#define SW_DIP6  0x0020
#define SW_DIP7  0x0040
#define SW_DIP8  0x0080
#define SW_DIP9  0x0100
#define SW_DIP10 0x0200
#define SW_DIP11 0x0400
#define SW_DIP12 0x0800

/* Programming voltage */
#define SW_VPP_12V 0x0000
#define SW_VPP_21V 0x1000

/* Other jumpers, which I haven't thought of a good name for yet */
#define SW_DIP3_A15 0x0000
#define SW_DIP3_S4  0x2000
#define SW_PIN1_VPP 0x0000
#define SW_PIN1_A18 0x4000


/* Some short-hand */
#define CHIP_read(A,B)    A->op.read( A, B)
#define CHIP_write(A,B)   A->op.write( A, B)
#define CHIP_isBlank(A,B) A->op.isBlank( A, B)

/* some variables with data defined elsewhere */
extern chip_info_t chip_info [];

/* and some useful functions */
chip_info_t *searchchipbyname( char *);

#endif
